@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Devise
   module Generators
     module OrmHelpers
@@ -23,7 +25,11 @@ CONTENT
       end
 
       def migration_path
-        @migration_path ||= File.join("db", "migrate")
+        if Rails.version >= '5.0.3'
+          db_migrate_path
+        else
+          @migration_path ||= File.join("db", "migrate")
+        end
       end
 
       def model_path
