@@ -1,4 +1,6 @@
 # encoding: UTF-8
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class ValidatableTest < ActiveSupport::TestCase
@@ -31,7 +33,7 @@ class ValidatableTest < ActiveSupport::TestCase
 
     %w{invalid_email_format 123 $$$ () ☃}.each do |email|
       user.email = email
-      assert user.invalid?, 'should be invalid with email ' << email
+      assert user.invalid?, "should be invalid with email #{email}"
       assert_equal 'is invalid', user.errors[:email].join
     end
 
@@ -42,7 +44,7 @@ class ValidatableTest < ActiveSupport::TestCase
   test 'should accept valid emails' do
     %w(a.b.c@example.com test_mail@gmail.com any@any.net email@test.br 123@mail.test 1☃3@mail.test).each do |email|
       user = new_user(email: email)
-      assert user.valid?, 'should be valid with email ' << email
+      assert user.valid?, "should be valid with email #{email}"
       assert_blank user.errors[:email]
     end
   end
@@ -97,7 +99,7 @@ class ValidatableTest < ActiveSupport::TestCase
 
     user.password_confirmation = 'confirmation'
     assert user.invalid?
-    assert_not (user.errors[:password].join =~ /is too long/)
+    refute (user.errors[:password].join =~ /is too long/)
   end
 
   test 'should complain about length even if password is not required' do
