@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module SharedAdmin
   extend ActiveSupport::Concern
 
@@ -8,7 +10,11 @@ module SharedAdmin
            allow_unconfirmed_access_for: 2.weeks, reconfirmable: true
 
     validates_length_of     :reset_password_token, minimum: 3, allow_blank: true
-    validates_uniqueness_of :email, allow_blank: true, if: :email_changed?
+    if Devise::Test.rails51?
+      validates_uniqueness_of :email, allow_blank: true, if: :will_save_change_to_email?
+    else
+      validates_uniqueness_of :email, allow_blank: true, if: :email_changed?
+    end
   end
 
   def raw_confirmation_token
