@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'active_support/test_case'
 
 class ActiveSupport::TestCase
@@ -50,6 +52,10 @@ class ActiveSupport::TestCase
     UserWithoutEmail.create!(valid_attributes(attributes))
   end
 
+  def create_user_with_validations(attributes={})
+    UserWithValidations.create!(valid_attributes(attributes))
+  end
+
   # Execute the block setting the given values and restoring old values after
   # the block is executed.
   def swap(object, new_values)
