@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Configurable < User
   devise :database_authenticatable, :confirmable, :rememberable, :timeoutable, :lockable,
          stretches: 15, pepper: 'abcdef', allow_unconfirmed_access_for: 5.days,
@@ -12,7 +14,7 @@ class UserWithValidation < User
   validates_presence_of :username
 end
 
-class UserWithCustomEncryption < User
+class UserWithCustomHashing < User
   protected
   def password_digest(password)
     password.reverse
